@@ -576,7 +576,7 @@ static void ensure_capa(int i) {
 /*
  * add eq string
  */
-static void def_eq(gint unused __attribute__((unused)), char *arg) {
+static void def_eq(gint unused, char *arg) {
   ensure_capa(nbEq);
   condStrings[nbEq++].eq = arg;
 }
@@ -584,7 +584,7 @@ static void def_eq(gint unused __attribute__((unused)), char *arg) {
 /*
  * add neq string
  */
-static void def_neq(gint unused __attribute__((unused)), char *arg) {
+static void def_neq(gint unused, char *arg) {
   ensure_capa(nbNEq);
   condStrings[nbNEq++].neq = arg;
 }
@@ -725,7 +725,7 @@ static void print(gint session, char *arg) {
  * print xmmsctrl help
  * the dummy variable is used just for convenience
  */
-static void print_help(__attribute__ ((unused)) gint dummy) {
+static void print_help(gint dummy) {
   unsigned int i;
 
   /* The string is cut to conform to ISO C89 */
